@@ -4,12 +4,12 @@ use strict;
 use warnings;
 use 5.008001;
 use ExtUtils::CppGuess;
-use Test::Alien 1.00 ();
+use Test::Alien 1.88 ();
 use Text::ParseWords qw( shellwords );
 use base qw( Exporter );
 
 # ABSTRACT: Testing tools for Alien modules for projects that use C++
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 
 our @EXPORT = @Test::Alien::EXPORT;
@@ -47,10 +47,16 @@ sub xs_ok
     my @new = ref($cppguess{$name}) eq 'ARRAY' ? @{ delete $cppguess{$name} } : shellwords(delete $cppguess{$name});
     my @old = do {
       my $value = delete $xs->{$stage{$name}}->{$name};
-      ref($value) eq 'ARRAY' ? @$value : shellwords($value);
+      !defined $value            ? ()
+        : ref($value) eq 'ARRAY' ? @$value
+        :                          shellwords($value);
     };
     $xs->{$stage{$name}}->{$name} = [@old, @new];
   }
+
+  $xs->{cbuilder_config} = delete $cppguess{config} if defined $cppguess{config};
+  $xs->{cbuilder_check} = 'have_cplusplus';
+
   warn "extra Module::Build option: $_" for keys %cppguess;
 
   $cb ? Test::Alien::xs_ok($xs, $message, $cb) : Test::Alien::xs_ok($xs, $message);
@@ -70,12 +76,12 @@ Test::Alien::CPP - Testing tools for Alien modules for projects that use C++
 
 =head1 VERSION
 
-version 1.01
+version 1.04
 
 =head1 SYNOPSIS
 
  use Test2::V0;
- use Test::Alien;
+ use Test::Alien::CPP;
  use Alien::libmycpplib;
  
  alien_ok 'ALien::libmycpplib';
@@ -139,9 +145,11 @@ Contributors:
 
 Roy Storey (KIWIROY)
 
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Graham Ollis.
+This software is copyright (c) 2017-2024 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
